api.customernetworks.v1 package — Argus-Toolbelt 1.0 documentation

# api.customernetworks.v1 package

## Submodules

## api.customernetworks.v1.network module

Autogenerated API

`api.customernetworks.v1.network.` `add_customer_network`(customer: str = None, location: str = None, flagsToSet: list = None, zone: str = None, description: str = None, networkAddress: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add new customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | customer (str) – Customer ID or short name of the customer that the network belongs to location (str) – Location ID or short name of the location where the network is located flagsToSet (list) – Flags to set for the network zone (str) – Zone of the network description (str) – Description of the customer network. Maximum number of characters is 255. => [sw{}$-().[]“‘_/,*+#:@!?;]* networkAddress (str) – IP address of the customer network => format:ip
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 308, “limit”: 804, “responseCode”: 200, “count”: 855, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “On determine firm upon.”, “messageTemplate”: “Tough avoid data adult individual.”, “field”: “Political across cost speech technology wear foot.”, “parameter”: {}, “timestamp”: 399254575}], “currentPage”: 134, “size”: 282}

`api.customernetworks.v1.network.` `add_customer_network_comment`(networkID: int, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add comment for customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network to update comment (str) – Comment to add to the network => [sw{}$-().[]“‘_/,*+#:@!?;]*
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 901, “limit”: 964, “responseCode”: 200, “count”: 977, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Bit project game may cup teacher store try.”, “messageTemplate”: “Source card before country others development.”, “field”: “Rule on serious thus month.”, “parameter”: {}, “timestamp”: 778392742}], “currentPage”: 169, “size”: 356}

`api.customernetworks.v1.network.` `delete_customer_network`(networkID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network to delete
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 765, “limit”: 428, “responseCode”: 200, “count”: 619, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Produce return agree American.”, “messageTemplate”: “Hand coach human issue result.”, “field”: “Nearly through herself painting.”, “parameter”: {}, “timestamp”: 1346339885}], “currentPage”: 20, “size”: 557}

`api.customernetworks.v1.network.` `delete_customer_network_comment`(networkID: int, commentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete comment from customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of parent network commentID (str) – ID of comment to delete
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 17, “limit”: 439, “responseCode”: 200, “count”: 803, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Money late this nature me apply moment challenge.”, “messageTemplate”: “Individual inside dream myself.”, “field”: “Before soon final program heavy government.”, “parameter”: {}, “timestamp”: 202526224}], “currentPage”: 452, “size”: 950}

`api.customernetworks.v1.network.` `get_customer_network`(networkID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network to get
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 418, “limit”: 711, “responseCode”: 200, “count”: 919, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Third mention every degree adult various available.”, “messageTemplate”: “Clear couple sell green memory score marriage.”, “field”: “Realize however wish compare answer deal.”, “parameter”: {}, “timestamp”: 701252332}], “currentPage”: 10, “size”: 397}

`api.customernetworks.v1.network.` `get_customer_network_comments`(networkID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get network’s comments (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network offset (int) – Skip a number of comments limit (int) – Maximum number of returned comments
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 928, “limit”: 297, “responseCode”: 200, “count”: 608, “data”: [{“id”: 116, “description”: “Receive series off wife.”, “lastUpdatedByUser”: {“id”: 977, “customerID”: 229, “userName”: “hmckee”, “name”: “Susan Hickman”}, “lastUpdatedTimestamp”: 569471383, “createdByUser”: {“id”: 449, “customerID”: 696, “userName”: “david84”, “name”: “Barbara Chapman”}, “createdTimestamp”: 1219940561, “zone”: “EXTERNAL”, “flags”: [“DNS”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Wonder defense side center dinner Mrs.”, “messageTemplate”: “Information weight suggest staff nice.”, “field”: “Red ever fill build your part manager.”, “parameter”: {}, “timestamp”: 1444717438}], “currentPage”: 516, “size”: 848}

`api.customernetworks.v1.network.` `get_customer_networks`(customerID: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get networks belonging to customer(s) (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – ID of customer(s) offset (int) – Skip a number of networks limit (int) – Maximum number of returned networks
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 533, “limit”: 59, “responseCode”: 200, “count”: 534, “data”: [{“id”: 83, “description”: “Program similar trade how civil.”, “lastUpdatedByUser”: {“id”: 195, “customerID”: 443, “userName”: “jennifer49”, “name”: “Kristin Brown”}, “lastUpdatedTimestamp”: 1474432781, “createdByUser”: {“id”: 471, “customerID”: 539, “userName”: “lowerypamela”, “name”: “Linda Andrade”}, “createdTimestamp”: 883349900, “zone”: “INTERNAL”, “flags”: [“GUEST”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Fact charge attorney size rate security technology.”, “messageTemplate”: “Record free moment out.”, “field”: “Himself though score all hit main.”, “parameter”: {}, “timestamp”: 1197705214}], “currentPage”: 927, “size”: 903}

`api.customernetworks.v1.network.` `search_customer_network`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, addresses: list = None, keywords: list = None, startTimestamp: int = None, endTimestamp: int = None, timeFieldStrategy: list = None, includeFlags: list = None, excludeFlags: list = None, includeSupernet: bool = 'True', includeSubnet: bool = 'True', timeMatchStrategy: str = 'any', includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. addresses (list) – A set of IP addresses matched against networks keywords (list) – A set of keywords matched against network’s description startTimestamp (int) – Start of time search period endTimestamp (int) – End of time search period timeFieldStrategy (list) – TimeFieldStrategy to define which timestamp field(s) to match. (default createdTimestamp) includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeSupernet (bool) – Network in search criteria will be searched for matching supernets (default true) includeSubnet (bool) – Network in search criteria will be searched for matching subnets (default true) timeMatchStrategy (str) – TimeMatchStrategy to define how to match startTimestamp and endTimestamp with provided timeFieldStrategies (default any) includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 608, “limit”: 368, “responseCode”: 200, “count”: 766, “data”: [{“id”: 435, “description”: “Certain per later story hope.”, “lastUpdatedByUser”: {“id”: 495, “customerID”: 556, “userName”: “xmcdonald”, “name”: “John Flores”}, “lastUpdatedTimestamp”: 1286783090, “createdByUser”: {“id”: 934, “customerID”: 639, “userName”: “pluna”, “name”: “Brian Nelson”}, “createdTimestamp”: 860003829, “zone”: “INTERNAL”, “flags”: [“SCANNER”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “We crime ask industry eight turn everything child.”, “messageTemplate”: “Author school three something money total.”, “field”: “Try kid real.”, “parameter”: {}, “timestamp”: 1396741697}], “currentPage”: 699, “size”: 551}

`api.customernetworks.v1.network.` `update_customer_network`(networkID: int, location: str = None, description: str = None, flagsToSet: list = None, flagsToEnable: list = None, flagsToDisable: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network to update location (str) – Location ID or short name of the location where the network is located description (str) – Description of the customer network. Maximum number of characters is 255. => [sw{}$-().[]“‘_/,*+#:@!?;]* flagsToSet (list) – Flags to set for the network. This property takes precedence over the content of flagsToEnable and flagsToDisable properties. flagsToEnable (list) – Flags to enable for the network flagsToDisable (list) – Flags to disable for the network
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 521, “limit”: 595, “responseCode”: 200, “count”: 54, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Bad improve drug success assume.”, “messageTemplate”: “Star blood her stand our his draw.”, “field”: “Compare rather source third.”, “parameter”: {}, “timestamp”: 629404596}], “currentPage”: 506, “size”: 483}

## Module contents